@@ -43,16 +43,14 @@ pub struct Theme {
     pub name: String,
     /// theme renderer
     pub renderer: Tera,
-    favicon: Vec<u8>,
-    logo: Vec<u8>,
-    feed: Vec<u8>,
     main_css: Vec<u8>,
     main_js: Vec<u8>,
+    atom: Vec<u8>,
     base: Vec<u8>,
     index: Vec<u8>,
     post: Vec<u8>,
     tag: Vec<u8>,
-    atom: Vec<u8>,
+    tags: Vec<u8>,
 }
 
 impl Theme {
@@ -71,41 +69,38 @@ impl Theme {
             if name != "simple" {
                 return Err(Error::ThemeNotFound(name.into()));
             }
-            theme.favicon.extend_from_slice(SIMPLE_FAVICON);
-            theme.logo.extend_from_slice(SIMPLE_LOGO);
-            theme.feed.extend_from_slice(SIMPLE_FEED);
             theme.main_css.extend_from_slice(SIMPLE_MAIN_CSS);
             theme.main_js.extend_from_slice(SIMPLE_MAIN_JS);
+            theme.atom.extend_from_slice(SIMPLE_ATOM);
             theme.base.extend_from_slice(SIMPLE_BASE);
             theme.index.extend_from_slice(SIMPLE_INDEX);
             theme.post.extend_from_slice(SIMPLE_POST);
             theme.tag.extend_from_slice(SIMPLE_TAG);
-            theme.atom.extend_from_slice(SIMPLE_ATOM);
+            theme.tags.extend_from_slice(SIMPLE_TAGS);
             theme.init_template()?;
             return Ok(theme);
         }
 
-        try_read_file!(src_dir, "static/favicon.png", &mut theme.favicon);
-        try_read_file!(src_dir, "static/logo.png", &mut theme.logo);
-        try_read_file!(src_dir, "static/feed.png", &mut theme.feed);
         try_read_file!(src_dir, "static/main.css", &mut theme.main_css);
         try_read_file!(src_dir, "static/main.js", &mut theme.main_js);
+        read_file(&src_dir.join("templates/atom.tpl"), &mut theme.atom)?;
         read_file(&src_dir.join("templates/base.tpl"), &mut theme.base)?;
         read_file(&src_dir.join("templates/index.tpl"), &mut theme.index)?;
         read_file(&src_dir.join("templates/post.tpl"), &mut theme.post)?;
         read_file(&src_dir.join("templates/tag.tpl"), &mut theme.tag)?;
-        read_file(&src_dir.join("templates/atom.tpl"), &mut theme.atom)?;
+        read_file(&src_dir.join("templates/tags.tpl"), &mut theme.tags)?;
         theme.init_template()?;
         return Ok(theme);
     }
 
     /// init renderer template.
     fn init_template(&mut self) -> Result<()> {
+        try_init_template!(self.renderer, "atom.tpl", self.atom);
         try_init_template!(self.renderer, "base.tpl", self.base);
         try_init_template!(self.renderer, "index.tpl", self.index);
         try_init_template!(self.renderer, "post.tpl", self.post);
         try_init_template!(self.renderer, "tag.tpl", self.tag);
-        try_init_template!(self.renderer, "atom.tpl", self.atom);
+        try_init_template!(self.renderer, "tags.tpl", self.tags);
         Ok(())
     }
 
@@ -117,16 +112,14 @@ impl Theme {
             return Ok(());
         }
         debug!("init theme({}) ...", name);
-        write_file(&dest_dir.join("static/favicon.png"), &self.favicon)?;
-        write_file(&dest_dir.join("static/logo.png"), &self.logo)?;
-        write_file(&dest_dir.join("static/feed.png"), &self.feed)?;
         write_file(&dest_dir.join("static/main.css"), &self.main_css)?;
         write_file(&dest_dir.join("static/main.js"), &self.main_js)?;
+        write_file(&dest_dir.join("templates/atom.tpl"), &self.atom)?;
         write_file(&dest_dir.join("templates/base.tpl"), &self.base)?;
         write_file(&dest_dir.join("templates/index.tpl"), &self.index)?;
         write_file(&dest_dir.join("templates/post.tpl"), &self.post)?;
         write_file(&dest_dir.join("templates/tag.tpl"), &self.tag)?;
-        write_file(&dest_dir.join("templates/atom.tpl"), &self.atom)?;
+        write_file(&dest_dir.join("templates/tags.tpl"), &self.tags)?;
         Ok(())
     }
 
@@ -135,22 +128,17 @@ impl Theme {
         debug!("exporting theme({}) static ...", self.name);
         let src_dir = self.root.join(&self.name);
         let dest_dir = root.as_ref();
-        try_write_file!(src_dir, dest_dir, "static/favicon.png", &self.favicon);
-        try_write_file!(src_dir, dest_dir, "static/logo.png", &self.logo);
-        try_write_file!(src_dir, dest_dir, "static/feed.png", &self.feed);
         try_write_file!(src_dir, dest_dir, "static/main.css", &self.main_css);
         try_write_file!(src_dir, dest_dir, "static/main.js", &self.main_js);
         Ok(())
     }
 }
 
-static SIMPLE_FAVICON: &[u8] = include_bytes!("simple_theme/static/favicon.png");
-static SIMPLE_LOGO: &[u8] = include_bytes!("simple_theme/static/logo.png");
-static SIMPLE_FEED: &[u8] = include_bytes!("simple_theme/static/feed.png");
-static SIMPLE_MAIN_CSS: &[u8] = include_bytes!("simple_theme/static/main.css");
-static SIMPLE_MAIN_JS: &[u8] = include_bytes!("simple_theme/static/main.js");
-static SIMPLE_BASE: &[u8] = include_bytes!("simple_theme/templates/base.tpl");
-static SIMPLE_INDEX: &[u8] = include_bytes!("simple_theme/templates/index.tpl");
-static SIMPLE_POST: &[u8] = include_bytes!("simple_theme/templates/post.tpl");
-static SIMPLE_TAG: &[u8] = include_bytes!("simple_theme/templates/tag.tpl");
-static SIMPLE_ATOM: &[u8] = include_bytes!("simple_theme/templates/atom.tpl");
+static SIMPLE_MAIN_CSS: &[u8] = include_bytes!("themes/simple/static/main.css");
+static SIMPLE_MAIN_JS: &[u8] = include_bytes!("themes/simple/static/main.js");
+static SIMPLE_ATOM: &[u8] = include_bytes!("themes/simple/templates/atom.tpl");
+static SIMPLE_BASE: &[u8] = include_bytes!("themes/simple/templates/base.tpl");
+static SIMPLE_INDEX: &[u8] = include_bytes!("themes/simple/templates/index.tpl");
+static SIMPLE_POST: &[u8] = include_bytes!("themes/simple/templates/post.tpl");
+static SIMPLE_TAG: &[u8] = include_bytes!("themes/simple/templates/tag.tpl");
+static SIMPLE_TAGS: &[u8] = include_bytes!("themes/simple/templates/tags.tpl");
